@@ -1,10 +1,6 @@
-from __future__ import absolute_import
-
 import functools
 import sys
 
-import six
-from past.builtins import map
 
 from . import blocks, exception, legos, primitives
 from .blocks import Aligned, Block, Checksum, Repeat, Request, REQUESTS, Size
@@ -191,8 +187,6 @@ __all__ = [
     "Word",
 ]
 
-__version__ = "0.4.1"
-
 
 # REQUEST MANAGEMENT
 def s_get(name=None):
@@ -285,15 +279,15 @@ def s_block(name=None, group=None, encoder=None, dep=None, dep_value=None, dep_v
     :param encoder:     (Optional, def=None) Optional pointer to a function to pass rendered data to prior to return
     :type  dep:         str, optional
     :param dep:         (Optional, def=None) Optional primitive whose specific value this block is dependant on
-    :type  dep_value:   Mixed, optional
+    :type  dep_value:   bytes, optional
     :param dep_value:   (Optional, def=None) Value that field "dep" must contain for block to be rendered
-    :type  dep_values:  List of Mixed Types, optional
+    :type  dep_values:  List of bytes, optional
     :param dep_values:  (Optional, def=None) Values that field "dep" may contain for block to be rendered
     :type  dep_compare: str, optional
     :param dep_compare: (Optional, def="==") Comparison method to use on dependency (==, !=, >, >=, <, <=)
     """
 
-    class ScopedBlock(object):
+    class ScopedBlock:
         def __init__(self, block):
             self.block = block
 
@@ -336,7 +330,7 @@ def s_aligned(modulus=1, pattern=b"\x00", name=None):
                         be given, defaults to None
     """
 
-    class ScopedAligned(object):
+    class ScopedAligned:
         def __init__(self, aligned):
             self.aligned = aligned
 
@@ -557,10 +551,10 @@ def s_update(name, value):
     :param value: Updated value
     """
 
-    if name not in map(lambda o: o.name, blocks.CURRENT.walk()):
+    if name not in map(lambda o: o.qualified_name, blocks.CURRENT.walk()):
         raise exception.SullyRuntimeError("NO OBJECT WITH NAME '%s' FOUND IN CURRENT REQUEST" % name)
 
-    blocks.CURRENT.names[name]._value = value
+    blocks.CURRENT.names[name]._default_value = value
 
 
 # PRIMITIVES
@@ -591,7 +585,7 @@ def s_binary(value, name=None):
         pair = parsed[:2]
         parsed = parsed[2:]
 
-        value += six.int2byte(int(pair, 16))
+        value += int(pair, 16).to_bytes(1, "little")
 
     blocks.CURRENT.push(Static(name=name, default_value=parsed))
 
@@ -772,12 +766,12 @@ def s_string(value="", size=None, padding=b"\x00", encoding="ascii", fuzzable=Tr
     )
 
 
-def s_from_file(value="", filename=None, encoding="ascii", fuzzable=True, max_len=0, name=None):
+def s_from_file(value=b"", filename=None, encoding="ascii", fuzzable=True, max_len=0, name=None):
     """
     Push a value from file onto the current block stack.
 
-    :type  value:    str
-    :param value:    (Optional, def="") Default string value
+    :type  value:    bytes
+    :param value:    (Optional, def=b"") Default bytes value
     :type  filename: str
     :param filename: (Optional, def=None) Filename pattern to load all fuzz value
     :type  encoding: str
