@@ -3,6 +3,7 @@ from .base_socket_connection import BaseSocketConnection
 from .file_connection import FileConnection
 from .iserial_like import ISerialLike
 from .itarget_connection import ITargetConnection
+from .netconf_connection import NETCONFConnection
 from .raw_l2_socket_connection import RawL2SocketConnection
 from .raw_l3_socket_connection import RawL3SocketConnection
 from .serial_connection import SerialConnection
@@ -11,12 +12,14 @@ from .socket_connection import SocketConnection
 from .ssl_socket_connection import SSLSocketConnection
 from .tcp_socket_connection import TCPSocketConnection
 from .udp_socket_connection import UDPSocketConnection
+from .unix_socket_connection import UnixSocketConnection
 
 __all__ = [
     "BaseSocketConnection",
     "FileConnection",
     "ISerialLike",
     "ITargetConnection",
+    "NETCONFConnection",
     "RawL2SocketConnection",
     "RawL3SocketConnection",
     "SerialConnection",
@@ -25,4 +28,5 @@ __all__ = [
     "SSLSocketConnection",
     "TCPSocketConnection",
     "UDPSocketConnection",
+    "UnixSocketConnection",
 ]
