@@ -1,11 +1,7 @@
-from __future__ import absolute_import
-
 import errno
 import socket
 import sys
 
-from future.utils import raise_
-
 from boofuzz import exception
 from boofuzz.connections import base_socket_connection
 
@@ -68,19 +64,17 @@ class RawL3SocketConnection(base_socket_connection.BaseSocketConnection):
             data = self._sock.recv(self.packet_size)
 
             if 0 < max_bytes < self.packet_size:
-                data = data[: self._packet_size]
+                data = data[: self.packet_size]
 
         except socket.timeout:
             data = b""
         except socket.error as e:
             if e.errno == errno.ECONNABORTED:
-                raise_(
-                    exception.BoofuzzTargetConnectionAborted(socket_errno=e.errno, socket_errmsg=e.strerror),
-                    None,
-                    sys.exc_info()[2],
-                )
+                raise exception.BoofuzzTargetConnectionAborted(
+                    socket_errno=e.errno, socket_errmsg=e.strerror
+                ).with_traceback(sys.exc_info()[2])
             elif e.errno in [errno.ECONNRESET, errno.ENETRESET, errno.ETIMEDOUT]:
-                raise_(exception.BoofuzzTargetConnectionReset(), None, sys.exc_info()[2])
+                raise exception.BoofuzzTargetConnectionReset().with_traceback(sys.exc_info()[2])
             elif e.errno == errno.EWOULDBLOCK:
                 data = b""
             else:
@@ -109,13 +103,11 @@ class RawL3SocketConnection(base_socket_connection.BaseSocketConnection):
 
         except socket.error as e:
             if e.errno == errno.ECONNABORTED:
-                raise_(
-                    exception.BoofuzzTargetConnectionAborted(socket_errno=e.errno, socket_errmsg=e.strerror),
-                    None,
-                    sys.exc_info()[2],
-                )
+                raise exception.BoofuzzTargetConnectionAborted(
+                    socket_errno=e.errno, socket_errmsg=e.strerror
+                ).with_traceback(sys.exc_info()[2])
             elif e.errno in [errno.ECONNRESET, errno.ENETRESET, errno.ETIMEDOUT, errno.EPIPE]:
-                raise_(exception.BoofuzzTargetConnectionReset(), None, sys.exc_info()[2])
+                raise exception.BoofuzzTargetConnectionReset().with_traceback(sys.exc_info()[2])
             else:
                 raise
 
