@@ -1,11 +1,9 @@
-from __future__ import division
-
 import atexit
 import sys
 import time
 import warnings
 
-from six import StringIO
+from io import StringIO
 
 try:
     import curses  # pytype: disable=import-error
@@ -18,22 +16,10 @@ import signal
 import threading
 
 from math import *
+from shutil import get_terminal_size
 from . import helpers
 from . import ifuzz_logger_backend
 
-if sys.version_info >= (3, 3):
-    from shutil import get_terminal_size
-else:
-    try:
-        from shutil_backports import get_terminal_size
-    except ImportError:
-        # Allow fuzz_logger_curses to be imported when shutil_backports is not available for install. Will fallback to a
-        # static-sized console window, but warn the user so they can correct the issue.
-        def get_terminal_size():
-            return [130, 40]
-
-        warnings.warn("Console GUI will not resize properly. Install shutil_backports for full support.", UserWarning)
-
 COLOR_PAIR_WHITE = 1
 COLOR_PAIR_CYAN = 2
 COLOR_PAIR_RED = 3
@@ -57,6 +43,7 @@ class FuzzLoggerCurses(ifuzz_logger_backend.IFuzzLoggerBackend):
     def __init__(
         self,
         web_port=26000,
+        web_address="localhost",
         window_height=40,
         window_width=130,
         auto_scroll=True,
@@ -97,6 +84,7 @@ class FuzzLoggerCurses(ifuzz_logger_backend.IFuzzLoggerBackend):
 
         self._title = "boofuzz"
         self._web_port = web_port
+        self._web_address = web_address
         self._max_log_lines = max_log_lines
         self._auto_scroll = auto_scroll
         self._current_data = None
@@ -118,7 +106,7 @@ class FuzzLoggerCurses(ifuzz_logger_backend.IFuzzLoggerBackend):
         self._current_num_mutations = 0
 
         self._format_raw_bytes = bytes_to_str
-        self._version = helpers.get_boofuzz_version(helpers)
+        self._version = helpers.get_boofuzz_version()
 
         # Resize console to minimum size
         self._width, self._height = get_terminal_size()
@@ -349,7 +337,7 @@ class FuzzLoggerCurses(ifuzz_logger_backend.IFuzzLoggerBackend):
         # Status Screen
         self._indent_size = 16
         self._statscr.addstr(1, 1, "Webinterface:")
-        self._statscr.addstr(1, self._indent_size, "localhost:{}".format(self._web_port))
+        self._statscr.addstr(1, self._indent_size, "{}:{}".format(self._web_address, self._web_port))
         self._statscr.addstr(2, 1, "Case:")
         # fmt: off
         self._statscr.addstr(2, self._indent_size, _progess_bar(self._current_index,
@@ -423,8 +411,9 @@ class FuzzLoggerCurses(ifuzz_logger_backend.IFuzzLoggerBackend):
 def _progess_bar(current, total, width):
     try:
         percent = current / total
-    except ZeroDivisionError:
+    except (ZeroDivisionError, TypeError):
         percent = 0
+        total = 0
     title_str = "{:7d} of {:7d} ".format(current, total)
     percent_str = " {:7.3f}%".format(percent * 100)
     bar_len = width - 4 - len(title_str) - len(percent_str)
