@@ -23,9 +23,9 @@ class NdrConformantArray(blocks.Block):
         if not self.value:
             raise exception.SullyRuntimeError("MISSING LEGO.ndr_conformant_array DEFAULT VALUE")
 
-        self.push(primitives.String(self.value))
+        self.push(primitives.String())
 
-    def render(self):
+    def render(self, mutation_context=None):
         """
         We overload and extend the render routine in order to properly pad and prefix the string.
 
@@ -63,7 +63,7 @@ class NdrString(blocks.Block):
         if not self.value:
             raise exception.SullyRuntimeError("MISSING LEGO.tag DEFAULT VALUE")
 
-        self.push(primitives.String(self.value))
+        self.push(primitives.String(name=name + "_STR", default_value=""))
 
     def render(self):
         """
@@ -114,7 +114,7 @@ class NdrWString(blocks.Block):
         if not self.value:
             raise exception.SullyRuntimeError("MISSING LEGO.tag DEFAULT VALUE")
 
-        self.push(primitives.String(self.value))
+        self.push(primitives.String())
 
     def render(self):
         """
