@@ -2,7 +2,7 @@ import attr
 
 
 @attr.s
-class Mutation(object):
+class Mutation:
     value = attr.ib(type=bytes)
     qualified_name = attr.ib(type=str)
     index = attr.ib(type=int)
