@@ -13,7 +13,9 @@
 # Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
 
-from .cluster import *
-from .edge import *
-from .graph import *
-from .node import *
+from .cluster import Cluster
+from .edge import Edge
+from .graph import Graph
+from .node import Node
+
+__all__ = ["Cluster", "Edge", "Graph", "Node"]
