@@ -5,11 +5,13 @@ from .byte import Byte
 from .bytes import Bytes
 from .delim import Delim
 from .dword import DWord
+from .float import Float
 from .from_file import FromFile
 from .group import Group
 from .mirror import Mirror
 from .qword import QWord
 from .random_data import RandomData
+from .simple import Simple
 from .static import Static
 from .string import String
 from .word import Word
@@ -21,11 +23,13 @@ __all__ = [
     "Bytes",
     "Delim",
     "DWord",
+    "Float",
     "FromFile",
     "Group",
     "Mirror",
     "QWord",
     "RandomData",
+    "Simple",
     "Static",
     "String",
     "Word",
