@@ -1,8 +1,4 @@
 import struct
-from builtins import range
-
-import six
-from past.builtins import map
 
 from .. import helpers
 from ..constants import LITTLE_ENDIAN
@@ -80,7 +76,7 @@ class BitField(Fuzzable):
     ):
         super(BitField, self).__init__(name=name, default_value=default_value, *args, **kwargs)
 
-        assert isinstance(width, six.integer_types), "width must be an integer!"
+        assert isinstance(width, int), "width must be an integer!"
 
         self.width = width
         self.max_num = max_num
@@ -92,13 +88,9 @@ class BitField(Fuzzable):
         if not self.max_num:
             self.max_num = binary_string_to_int("1" + "0" * width)
 
-        assert isinstance(self.max_num, six.integer_types), "max_num must be an integer!"
+        assert isinstance(self.max_num, int), "max_num must be an integer!"
 
-    def _iterate_fuzz_lib(self):
-        if self.full_range:
-            for i in range(0, self.max_num):
-                yield i
-        else:
+        if not self.full_range:
             # try only "smart" values.
             interesting_boundaries = [
                 0,
@@ -110,8 +102,30 @@ class BitField(Fuzzable):
                 self.max_num // 32,
                 self.max_num,
             ]
-            for boundary in interesting_boundaries:
-                for v in self._yield_integer_boundaries(boundary):
+
+            # Contract: sort in ascending order required for deduplication.
+            interesting_boundaries.sort()
+
+            self._interesting_boundaries = interesting_boundaries
+        else:
+            self._interesting_boundaries = []
+
+    def _iterate_fuzz_lib(self):
+        if self.full_range:
+            for i in range(0, self.max_num):
+                yield i
+        else:
+            # To avoid duplication of mutatation values, we introduce gradually
+            # increasing lower border. Combined with interesting boundaries
+            # sorted in ascending order, it's possible to avoid duplicates.
+            # Deduplication could also be done with intermediate 'set' construction,
+            # but it might be costly or impossible if the number of values is huge.
+            # We don't expect negative bit field values with Python integers,
+            # the 0-value for mutation is possible with the given starting 'lower_border'.
+            lower_border = -1
+            for boundary in self._interesting_boundaries:
+                for v in self._yield_integer_boundaries(boundary, lower_border):
+                    lower_border = v
                     yield v
         # TODO Add a way to inject a list of fuzz values
         # elif isinstance(default_value, (list, tuple)):
@@ -120,16 +134,19 @@ class BitField(Fuzzable):
 
         # TODO: Add injectable arbitrary bit fields
 
-    def _yield_integer_boundaries(self, integer):
+    def _yield_integer_boundaries(self, integer, lower_border):
         """
         Add the supplied integer and border cases to the integer fuzz heuristics library.
 
         @type  integer: int
         @param integer: int to append to fuzz heuristics
+        @type  lower_border: int
+        @param lower_border: int bottom limit for border cases, so all values must be strictly greater
         """
+        # Contract: generate values in ascending order, otherwise deduplication logics might break.
         for i in range(-10, 10):
             case = integer + i
-            if 0 <= case < self.max_num:
+            if lower_border < case < self.max_num:
                 # some day: if case not in self._user_provided_values
                 yield case
 
