@@ -25,8 +25,6 @@
 import json
 from io import open
 
-from past.builtins import xrange
-
 
 class CrashBinStruct:
     def __init__(self):
@@ -96,7 +94,7 @@ class CrashBinning:
         crash.extra = extra
 
         # add module names to the stack unwind.
-        for i in xrange(len(crash.stack_unwind)):
+        for i in range(len(crash.stack_unwind)):
             addr = crash.stack_unwind[i]
             module = pydbg.addr_to_module(addr)
 
@@ -108,7 +106,7 @@ class CrashBinning:
             crash.stack_unwind[i] = "%s:%08x" % (module, addr)
 
         # add module names to the SEH unwind.
-        for i in xrange(len(crash.seh_unwind)):
+        for i in range(len(crash.seh_unwind)):
             (addr, handler) = crash.seh_unwind[i]
 
             module = pydbg.addr_to_module(handler)
@@ -161,7 +159,7 @@ class CrashBinning:
         synopsis += crash.context_dump
 
         synopsis += "\ndisasm around:\n"
-        for (ea, inst) in crash.disasm_around:
+        for ea, inst in crash.disasm_around:
             synopsis += "\t0x%08x %s\n" % (ea, inst)
 
         if len(crash.stack_unwind):
@@ -171,7 +169,7 @@ class CrashBinning:
 
         if len(crash.seh_unwind):
             synopsis += "\nSEH unwind:\n"
-            for (addr, handler, handler_str) in crash.seh_unwind:
+            for addr, handler, handler_str in crash.seh_unwind:
                 synopsis += "\t%08x -> %s\n" % (addr, handler_str)
 
         return synopsis + "\n"
@@ -217,7 +215,7 @@ class CrashBinning:
 
         self.bins = {}
         bin_dict = json.load(open(file_name, "rb"))
-        for (crash_address, bin_list) in bin_dict.items():
+        for crash_address, bin_list in bin_dict.items():
             self.bins[crash_address] = []
             for single_bin in bin_list:
                 tmp = CrashBinStruct()
@@ -254,7 +252,7 @@ class CrashBinning:
         synopsis += self.last_crash.context_dump
 
         synopsis += "\ndisasm around:\n"
-        for (ea, inst) in self.last_crash.disasm_around:
+        for ea, inst in self.last_crash.disasm_around:
             synopsis += "\t0x%08x %s\n" % (ea, inst)
 
         if len(self.last_crash.stack_unwind):
@@ -264,7 +262,7 @@ class CrashBinning:
 
         if len(self.last_crash.seh_unwind):
             synopsis += "\nSEH unwind:\n"
-            for (addr, handler, handler_str) in self.last_crash.seh_unwind:
+            for addr, handler, handler_str in self.last_crash.seh_unwind:
                 try:
                     disasm = self.pydbg.disasm(handler)
                 except Exception:
