@@ -1,11 +1,6 @@
-from __future__ import absolute_import
-
 import math
 import struct
 
-import six
-from past.builtins import xrange
-
 from ..helpers import crc16
 
 
@@ -13,11 +8,11 @@ def dnp3(data, control_code=b"\x44", src=b"\x00\x00", dst=b"\x00\x00"):
     num_packets = int(math.ceil(float(len(data)) / 250.0))
     packets = []
 
-    for i in xrange(num_packets):
+    for i in range(num_packets):
         packet_slice = data[i * 250 : (i + 1) * 250]
 
         p = b"\x05\x64"
-        p += six.int2byte(len(packet_slice))
+        p += len(packet_slice).to_bytes(1, "little")
         p += control_code
         p += dst
         p += src
@@ -39,9 +34,9 @@ def dnp3(data, control_code=b"\x44", src=b"\x00\x00", dst=b"\x00\x00"):
         if i == num_packets - 1:
             frag_number |= 0x80
 
-        p += six.int2byte(frag_number)
+        p += frag_number.to_bytes(1, "little")
 
-        for x in xrange(num_chunks):
+        for x in range(num_chunks):
             chunk = packet_slice[i * 16 : (i + 1) * 16]
             chksum = struct.pack("<H", crc16(chunk))
             p += chksum + chunk
