@@ -2,7 +2,7 @@ import attr
 
 
 @attr.s
-class ProtocolSession(object):
+class ProtocolSession:
     """Contains a ``session_variables`` dictionary used to store data specific to a single fuzzing test case.
 
     Generally, values in ``session_variables`` will be set in a callback function, e.g. ``post_test_case_callbacks``
